@@ -174,7 +174,7 @@ sub init_class {# from plugin! init Class vars
   $init_conf ||= $c;
   $c->{pos} ||= {};
   $c->{pos}{schema} ||= 'public';
-  $c->{pos}{schema} = qq{"$c->{pos}{schema}".};
+  #~ $c->{pos}{schema} = qq{"$c->{pos}{schema}".};
   $c->{pos}{file} ||= 'POS/Pg.pm';
   $c->{dbh} ||= $dbh ||=  $args{dbh};
   $dbh ||= $c->{dbh};
